@@ -65,7 +65,7 @@ test_that("print compareCategory summary when categories are equivalent", {
 })
 
 with_mock_crunch({
-    ds1 <- loadDataset("test ds")
+    ds1 <- cachedLoadDataset("test ds")
     ds2 <- loadDataset("an archived dataset", "archived")
 
     test_that("compareVariables", {
